@@ -2,11 +2,12 @@
 #'
 #' @export
 #' @param x Variety of things, character, list, or ckan_related class object
-#' @param ... Further args passed on to \code{\link{related_show}} if character given
+#' @param ... Further args passed on to [related_show()] if character given
 #' @examples \dontrun{
-#' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/",
+#' key = getOption("ckan_demo_key"))
 #'
-#' (x <- package_create("foobbbbbarrrr") %>%
+#' (x <- package_create("foobbbbbarrrrr") %>%
 #'    related_create(title = "my resource",
 #'                   type = "visualization"))
 #'
@@ -42,7 +43,10 @@ print.ckan_related <- function(x, ...) {
   cat("  Creator: ", x$created, "\n", sep = "")
 }
 
-get_related <- function(id, url = get_default_url(), key = get_default_key(), ...) {
-  res <- ckan_GET(url, 'related_show', list(id = id), key = key, ...)
+get_related <- function(id, url = get_default_url(),
+  key = get_default_key(), ...) {
+  
+  res <- ckan_GET(url, 'related_show', list(id = id), key = key,
+    opts = list(...))
   as_ck(jsl(res), "ckan_related")
 }
