@@ -20,6 +20,7 @@ dashboard_activity_list <- function(limit = 31, offset = 0,
   url = get_default_url(), key = get_default_key(), as = 'list', ...) {
 
   args <- list(limit = limit, offset = offset)
-  res <- ckan_GET(url, 'dashboard_activity_list', args, key = key, ...)
+  res <- ckan_GET(url, 'dashboard_activity_list', args, key = key,
+    opts = list(...))
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
