@@ -19,6 +19,6 @@ dashboard_count <- function(url = get_default_url(), key = get_default_key(),
   as = 'list', ...) {
 
   res <- ckan_GET(url, 'dashboard_new_activities_count', list(), key = key,
-    ...)
+    opts = list(...))
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
