@@ -3,6 +3,8 @@
 #' @export
 #' @param x (list) A list with key-value pairs
 #' @param id (character) Package identifier
+#' @param http_method (character) which HTTP method (verb) to use; one of 
+#' "GET" or "POST". Default: "GET"
 #' @template args
 #' @template key
 #' @examples \dontrun{
@@ -22,10 +24,10 @@
 #' # Then update the packge
 #' package_update(x, pkg$id)
 #' }
-package_update <- function(x, id, url = get_default_url(),
+package_update <- function(x, id, http_method = "GET", url = get_default_url(),
                            key = get_default_key(), as = 'list', ...) {
 
-  id <- as.ckan_package(id, url = url, key = key)
+  id <- as.ckan_package(id, url = url, key = key, http_method = http_method)
   if (class(x) != "list") {
     stop("x must be of class list", call. = FALSE)
   }
